backbone: Extract the backbone from a network

View source: R/backbone.R

backboneR Documentation

Extract the backbone from a network

Description

backbone() extracts the backbone from a weighted or unweighted network

Usage

backbone(N, narrative = TRUE, ...)

Arguments

N

A network represented as a matrix, Matrix, or igraph object

narrative

logical: display suggested text & citations

...

Optional arguments

Details

Given a weighted and/or dense network, the backbone is an sparse and unweighted subgraph that contains only the most "important" edges.

backbone() is a wrapper that detects the type of network in N, then extracts the backbone using the appropriate ⁠backbone_from_*()⁠ function:

  • If N is a weighted network, backbone_from_weighted()

  • If N is a bipartite network or hypergraph, backbone_from_projection()

  • If N is an unweighted network, backbone_from_unweighted()

Designed as a user-friendly wrapper, backbone() uses the defaults for the underlying functions, which should work in many cases, and which can be modified by passing optional arguments. Unlike the underlying functions, by default backbone() displays narrative text describing what it did so that you know.

For details about the backbone models, see the documentation for the underlying functions above. For an overview of the package with examples, please see the Introduction to Backbone using vignette("backbone"). For a detailed empirical example, please see the U.S. Senate Example using vignette("senate108").

Value

A backbone in the same class as N

References

package: Neal, Z. P. (2026). backbone: An R Package to Extract Network Backbones. PLOS One, 21, e0349258. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1371/journal.pone.0349258")}

Examples

N <- igraph::sample_gnp(100, .3)  #A random unweighted network
backbone(N)


backbone documentation built on May 21, 2026, 1:06 a.m.