| disparity | R Documentation |
disparity() was replaced by backbone_from_weighted(model = "disparity").
disparity(
W,
alpha = 0.05,
missing.as.zero = FALSE,
signed = FALSE,
mtc = "none",
narrative = FALSE
)
W |
A positively-weighted unipartite graph as a binary incidence matrix or a binary bipartite igraph object |
alpha |
real: significance level of hypothesis test(s) |
missing.as.zero |
boolean: should missing edges be treated as edges with zero weight and tested for significance |
signed |
boolean: TRUE for a signed backbone, FALSE for a binary backbone (see details) |
mtc |
string: type of Multiple Test Correction to be applied; can be any method allowed by |
narrative |
boolean: TRUE if suggested text & citations should be displayed. #' |
See backbone v2.1.4 for original documentation
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.