fdsm: Depricated function to extract Fixed Degree Sequence Model...

View source: R/depricated.R

fdsmR Documentation

Depricated function to extract Fixed Degree Sequence Model (FDSM) backbone

Description

fdsm() was replaced by backbone_from_projection(model = "fdsm").

Usage

fdsm(
  B,
  alpha = 0.05,
  missing.as.zero = FALSE,
  signed = FALSE,
  mtc = "none",
  narrative = FALSE,
  trials = NULL
)

Arguments

B

An unweighted bipartite network as a binary incidence matrix or a binary bipartite igraph object

alpha

real: significance level of hypothesis test(s)

missing.as.zero

boolean: treat missing edges as edges with zero weight and test them for significance

signed

boolean: return a signed backbone

mtc

string: type of Multiple Test Correction, either "none" or a method allowed by p.adjust().

narrative

boolean: display suggested text & citations

trials

numeric: the number of bipartite graphs generated using fastball to approximate the edge weight distribution

Details

See backbone v2.1.4 for original documentation


backbone documentation built on May 21, 2026, 1:06 a.m.