sdsm: Depricated function to extract Stochastic Degree Sequence...

View source: R/depricated.R

sdsmR Documentation

Depricated function to extract Stochastic Degree Sequence Model (SDSM) backbone

Description

sdsm() was replaced by backbone_from_projection(model="sdsm").

Usage

sdsm(
  B,
  alpha = 0.05,
  missing.as.zero = FALSE,
  signed = FALSE,
  mtc = "none",
  narrative = FALSE
)

Arguments

B

An unweighted bipartite network as a binary incidence matrix or a binary bipartite igraph object

alpha

real: significance level of hypothesis test(s)

missing.as.zero

boolean: treat missing edges as edges with zero weight and test them for significance

signed

boolean: return a signed backbone

mtc

string: type of Multiple Test Correction, either "none" or a method allowed by p.adjust().

narrative

boolean: display suggested text & citations

Details

See backbone v2.1.4 for original documentation


backbone documentation built on May 21, 2026, 1:06 a.m.