| backbone | R Documentation |
backbone() extracts the backbone from a weighted or unweighted network
backbone(N, narrative = TRUE, ...)
N |
A network represented as a matrix, Matrix, or igraph object |
narrative |
logical: display suggested text & citations |
... |
Optional arguments |
Given a weighted and/or dense network, the backbone is an sparse and unweighted subgraph that contains only the most "important" edges.
backbone() is a wrapper that detects the type of network in N, then extracts the backbone
using the appropriate backbone_from_*() function:
If N is a weighted network, backbone_from_weighted()
If N is a bipartite network or hypergraph, backbone_from_projection()
If N is an unweighted network, backbone_from_unweighted()
Designed as a user-friendly wrapper, backbone() uses the defaults for the underlying functions,
which should work in many cases, and which can be modified by passing optional arguments. Unlike
the underlying functions, by default backbone() displays narrative text describing what it did
so that you know.
For details about the backbone models, see the documentation for the underlying functions above. For
an overview of the package with examples, please see the Introduction to
Backbone using vignette("backbone"). For a detailed empirical example, please see the
U.S. Senate Example using vignette("senate108").
A backbone in the same class as N
package: Neal, Z. P. (2026). backbone: An R Package to Extract Network Backbones. PLOS One, 21, e0349258. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1371/journal.pone.0349258")}
N <- igraph::sample_gnp(100, .3) #A random unweighted network
backbone(N)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.