| sdsm | R Documentation |
sdsm() was replaced by backbone_from_projection(model="sdsm").
sdsm(
B,
alpha = 0.05,
missing.as.zero = FALSE,
signed = FALSE,
mtc = "none",
narrative = FALSE
)
B |
An unweighted bipartite network as a binary incidence matrix or a binary bipartite igraph object |
alpha |
real: significance level of hypothesis test(s) |
missing.as.zero |
boolean: treat missing edges as edges with zero weight and test them for significance |
signed |
boolean: return a signed backbone |
mtc |
string: type of Multiple Test Correction, either |
narrative |
boolean: display suggested text & citations |
See backbone v2.1.4 for original documentation
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.